﻿/*
Function to add an entry to the scenariolog table

Inputs: version,io,schema_name,table_name,script_name,comment
Outputs:
	id 		SERIAL,
	version 	text,
	io 		text,
	schema_name 	text,
	table_name 	text,
	script_name 	text,
	entries 	integer,
	"comment" 	text,
	user_name 	text,
	"timestamp" 	timestamp,
	metadata 	text

__copyright__ 	= "© Reiner Lemoine Institut"
__license__ 	= "GNU Affero General Public License Version 3 (AGPL-3.0)"
__author__ 	= "Ludwig Huelk"
*/

-- scenario list
DROP TABLE IF EXISTS	model_draft.scenariolist CASCADE;
CREATE TABLE 		model_draft.scenariolist (
	version 	text,
	version_name	text,
	"release"	boolean,
	"comment"	text,
	"timestamp"	timestamp,
	CONSTRAINT scenariolist_pkey PRIMARY KEY (version));

-- grant
ALTER TABLE		model_draft.scenariolist OWNER TO role_user;
GRANT SELECT ON TABLE	model_draft.scenariolist TO role_read;

-- scenario
INSERT INTO	model_draft.scenariolist (version,version_name,release,comment,timestamp) VALUES
	('v0', 'setup', 'FALSE', 'setup database and scenario log', '2017-04-18'),
	('v1', 'qgis', 'FALSE', 'geodata', '2017-04-18');

-- metadata
COMMENT ON TABLE model_draft.scenariolist IS '{
	"title": "Scenario List",
	"description": "Versions",
	"language": [ "eng", "ger" ],
	"reference_date": " ",
	"sources": [
		{"name": " ", "description": " ","url": " ", "license": " ", "copyright": " "} ],
	"spatial": [
		{"extend": "",
		"resolution": ""} ],
	"license": [
		{"id": 	"ODbL-1.0",
		"name": "Open Data Commons Open Database License 1.0",
		"version": "1.0",
		"url": "https://opendatacommons.org/licenses/odbl/1.0/",
		"instruction": "You are free: To Share, To Create, To Adapt; As long as you: Attribute, Share-Alike, Keep open!",
		"copyright": "© Reiner Lemoine Institut"} ],
	"contributors": [
		{"name": "Ludee", "email": " ", "date": "2016-10-01", "comment": "Create table" },
		{"name": "Ludee", "email": " ", "date": "2016-11-16", "comment": "Add metadata" },
		{"name": "Ludee", "email": " ", "date": "2017-03-21", "comment": "Update metadata to 1.1"},
		{"name": "Ludee", "email": " ", "date": "2017-04-06", "comment": "Update metadata to 1.2"},
		{"name": "Ludee", "email": " ", "date": "2017-04-18", "comment": "Generalize"} ],
	"resources": [{
		"schema": {
			"fields": [
				{"name": "version", "description": "scenario version number", "unit": "" },
				{"name": "version_name", "description": "version name", "unit": "" },
				{"name": "release", "description": "external release", "unit": "" },
				{"name": "comment", "description": "additional information and comments", "unit": "" },
				{"name": "timestamp", "description": "timestamp (Berlin)", "unit": "" } ]},
		"meta_version": "1.2"}] }' ;
SELECT obj_description('model_draft.scenariolist' ::regclass) ::json;

-- scenariolog
DROP TABLE IF EXISTS	model_draft.scenariolog CASCADE;
CREATE TABLE 		model_draft.scenariolog (
	id 		SERIAL,
	version 	text,
	io 		text,
	schema_name 	text,
	table_name 	text,
	script_name 	text,
	entries 	integer,
	"comment" 	text,
	user_name 	text,
	"timestamp" 	timestamp,
	metadata 	text,
	CONSTRAINT scenariolog_pkey PRIMARY KEY (id));

-- grant
ALTER TABLE		model_draft.scenariolog OWNER TO role_user; 
GRANT SELECT ON TABLE	model_draft.scenariolog TO role_read;

-- metadata
COMMENT ON TABLE model_draft.scenariolog IS '{
	"title": "Scenario Log",
	"description": "Database logging",
	"language": [ "eng"],
	"reference_date": "2017-04-18",
	"sources": [
		{"name": " ", "description": " ","url": " ", "license": " ", "copyright": " "} ],
	"spatial": [
		{"extend": "",
		"resolution": ""} ],
	"license": [
		{"id": 	"ODbL-1.0",
		"name": "Open Data Commons Open Database License 1.0",
		"version": "1.0",
		"url": "https://opendatacommons.org/licenses/odbl/1.0/",
		"instruction": "You are free: To Share, To Create, To Adapt; As long as you: Attribute, Share-Alike, Keep open!",
		"copyright": "© Reiner Lemoine Institut"} ],
	"contributors": [
		{"name": "Ludee", "email": " ", "date": "2016-12-01", "comment": "Create table"},
		{"name": "Ludee", "email": " ", "date": "2017-01-18", "comment": "Update metadata"},
		{"name": "Ludee", "email": " ", "date": "2017-04-18", "comment": "Generalize"}],
	"resources": [{
		"schema": {
			"fields": [
				{"name": "id", "description": "unique identifier", "unit": "" },
				{"name": "version", "description": "internal version number", "unit": "" },
				{"name": "io", "description": "setup, input, output, temp", "unit": "" },
				{"name": "schema_name", "description": "schema", "unit": "" },
				{"name": "table_name", "description": "table", "unit": "" },
				{"name": "script_name", "description": "source", "unit": "" },
				{"name": "entries", "description": "number of rows", "unit": "" },
				{"name": "comment", "description": "additional info", "unit": "" },
				{"name": "user_name", "description": "database user", "unit": "" },
				{"name": "timestamp", "description": "current time", "unit": "" },
				{"name": "metadata", "description": "copy of the metadata", "unit": "" } ]},
		"meta_version": "1.2"}] }' ;
SELECT obj_description('model_draft.scenariolog' ::regclass) ::json;

-- function
DROP FUNCTION IF EXISTS 	scenariolog(text,text,text,text,text,text);
CREATE OR REPLACE FUNCTION 	scenariolog(text,text,text,text,text,text)
	RETURNS int AS $PROC$
	DECLARE
	_version 	ALIAS FOR $1;
	_io 		ALIAS FOR $2;
	_schema_name 	ALIAS FOR $3;
	_table_name 	ALIAS FOR $4;
	_script_name 	ALIAS FOR $5;
	_comment 	ALIAS FOR $6;
	BEGIN
		EXECUTE 'INSERT INTO model_draft.scenariolog ' ||
			'(version,io,schema_name,table_name,script_name,entries,comment,user_name,timestamp,metadata)
			SELECT ' || quote_literal(_version) || ',' || 
				quote_literal(_io) || ',' ||
				quote_literal(_schema_name) || ',' ||
				quote_literal(_table_name) || ',' ||
				quote_literal(_script_name) || ',' ||
				'COUNT(*),' ||
				quote_literal(_comment) || ',' || 
				'session_user,' ||
				E'NOW() AT TIME ZONE \'Europe/Berlin\' ,' ||
				E'obj_description(\'' || _schema_name || '.' || _table_name  || E'\' ::regclass) ::json ' || 
			'FROM '	|| _schema_name || '.' || _table_name || ';' ;
		RETURN 1;
	END;
	$PROC$ LANGUAGE plpgsql;

-- grant
ALTER FUNCTION			scenariolog(text,text,text,text,text,text) OWNER TO role_admin;
GRANT EXECUTE ON FUNCTION 	scenariolog(text,text,text,text,text,text) TO role_user;

-- scenariolog (version,io,schema_name,table_name,script_name,comment)
SELECT scenariolog('v0','output','model_draft','scenariolist','function_scenariolog.sql','Scenario List');
SELECT scenariolog('v0','output','model_draft','scenariolog','function_scenariolog.sql','Scenario Log');
