/*
create some data

__copyright__ 	= "© Reiner Lemoine Institut"
__license__ 	= "GNU Affero General Public License Version 3 (AGPL-3.0)"
__author__ 	= "Ludwig Huelk"
*/


-- powerplant
DROP TABLE IF EXISTS 	model_draft.powerplant CASCADE;
CREATE TABLE		model_draft.powerplant (
	id 		serial,
	technology 	text,
	capacity	double precision,
	geom 		geometry(Point,3035),
	CONSTRAINT powerplant_pkey PRIMARY KEY (id));

-- insert
INSERT INTO	model_draft.powerplant (technology,capacity,geom)
SELECT 'PV',20, ST_SetSRID(ST_GeomFromText('POINT(4215214.907 3002990.019)'),3035) ::geometry(Point,3035) UNION ALL
SELECT 'PV',30, ST_SetSRID(ST_GeomFromText('POINT(4215315.717 3004016.005)'),3035) ::geometry(Point,3035) UNION ALL
SELECT 'PV',11, ST_SetSRID(ST_GeomFromText('POINT(4214984.020 3006313.498)'),3035) ::geometry(Point,3035) UNION ALL
SELECT 'PV',25, ST_SetSRID(ST_GeomFromText('POINT(4216049.029 3005841.967)'),3035) ::geometry(Point,3035) UNION ALL
SELECT 'PV',32, ST_SetSRID(ST_GeomFromText('POINT(4217943.282 3002959.125)'),3035) ::geometry(Point,3035) UNION ALL
SELECT 'PV',10, ST_SetSRID(ST_GeomFromText('POINT(4219299.340 3004266.404)'),3035) ::geometry(Point,3035) UNION ALL
SELECT 'PV',15, ST_SetSRID(ST_GeomFromText('POINT(4217240.864 3005887.495)'),3035) ::geometry(Point,3035) UNION ALL
SELECT 'PV',50, ST_SetSRID(ST_GeomFromText('POINT(4217196.963 3007183.391)'),3035) ::geometry(Point,3035) UNION ALL
SELECT 'PV',30, ST_SetSRID(ST_GeomFromText('POINT(4219245.683 3004702.164)'),3035) ::geometry(Point,3035) UNION ALL
SELECT 'PV',100, ST_SetSRID(ST_GeomFromText('POINT(4218709.114 3007493.951)'),3035) ::geometry(Point,3035) UNION ALL
SELECT 'Wind',500, ST_SetSRID(ST_GeomFromText('POINT(4218666.838 3007984.994)'),3035) ::geometry(Point,3035) UNION ALL
SELECT 'Wind',500, ST_SetSRID(ST_GeomFromText('POINT(4218813.176 3008108.567)'),3035) ::geometry(Point,3035) UNION ALL
SELECT 'Wind',500, ST_SetSRID(ST_GeomFromText('POINT(4219086.338 3007848.412)'),3035) ::geometry(Point,3035) UNION ALL
SELECT 'Wind',1000, ST_SetSRID(ST_GeomFromText('POINT(4216367.719 3002066.469)'),3035) ::geometry(Point,3035) UNION ALL
SELECT 'Wind',2000, ST_SetSRID(ST_GeomFromText('POINT(4220374.105 3005598.072)'),3035) ::geometry(Point,3035) ;

-- index
CREATE INDEX	powerplant_geom_idx
	ON	model_draft.powerplant USING GIST (geom);

-- grant
ALTER TABLE		model_draft.powerplant OWNER TO role_user;
GRANT SELECT ON TABLE	model_draft.powerplant TO role_read;

-- metadata
COMMENT ON TABLE model_draft.powerplant IS '{
	"title": "Renewable powerplant",
	"description": "sample data",
	"language": [ "eng" ],
	"reference_date": "2017-04-19",
	"sources": [
		{"name": " ", "description": " ","url": " ", "license": " ", "copyright": " "} ],
	"spatial": [
		{"extend": "Test area",
		"resolution": ""} ],
	"license": [
		{"id": "ODbL-1.0",
		"name": "Open Data Commons Open Database License 1.0",
		"version": "1.0",
		"url": "https://opendatacommons.org/licenses/odbl/1.0/",
		"instruction": "You are free: To Share, To Create, To Adapt; As long as you: Attribute, Share-Alike, Keep open!",
		"copyright": " "} ],
	"contributors": [
		{"name": "Ludee", "email": " ", "date": "2017-04-18", "comment": "Create data"} ],
	"resources": [{
		"schema": {
			"fields": [
				{"name": "id", "description": "unique identifier", "unit": "" },
				{"name": "technology", "description": "wind or pv", "unit": "" },
				{"name": "capacity", "description": "installed capacity", "unit": "kW" },
				{"name": "geom", "description": "geometry", "unit": "" } ]},
		"meta_version": "1.2"}] }';
SELECT obj_description('model_draft.powerplant' ::regclass) ::json;

-- scenariolog (version,io,schema_name,table_name,script_name,comment)
SELECT scenariolog('v1','output','model_draft','powerplant','make_data.sql',' ');
