/*
create some data

__copyright__ 	= "© Reiner Lemoine Institut"
__license__ 	= "GNU Affero General Public License Version 3 (AGPL-3.0)"
__author__ 	= "Ludwig Huelk"
*/


-- powerplants per municipality
DROP TABLE IF EXISTS 	model_draft.powerplant_per_mun CASCADE;
CREATE TABLE		model_draft.powerplant_per_mun (
	id 		integer,
	geom 		geometry(MultiPolygon,3035),
	geom_point	geometry(Point,3035),
	pv_cap		double precision,
	pv_cnt		integer,
	wind_cap	double precision,
	wind_cnt	integer,
	sum_cap		double precision,
	sum_cnt		integer,
	CONSTRAINT powerplant_per_mun_pkey PRIMARY KEY (id));

-- fkey
ALTER TABLE model_draft.powerplant_per_mun
	ADD CONSTRAINT powerplant_per_mun_fkey FOREIGN KEY (id) 
		REFERENCES boundaries.bkg_vg250_6_gem_hessen (id) MATCH SIMPLE ON UPDATE NO ACTION ON DELETE NO ACTION;

-- index
CREATE INDEX	powerplant_per_mun_geom_idx
	ON	model_draft.powerplant_per_mun USING GIST (geom);

-- grant
ALTER TABLE		model_draft.powerplant_per_mun OWNER TO role_user;
GRANT SELECT ON TABLE	model_draft.powerplant_per_mun TO role_read;

-- insert transformed geom
INSERT INTO	model_draft.powerplant_per_mun (id,geom,geom_point)
	SELECT	id,
		ST_TRANSFORM(geom,3035),
		ST_CENTROID(ST_TRANSFORM(geom,3035))
	FROM	boundaries.bkg_vg250_6_gem_hessen;

-- pv
UPDATE 	model_draft.powerplant_per_mun AS t1
	SET  	pv_cap = t2.pv_cap,
		pv_cnt = t2.pv_cnt
	FROM	(SELECT	a.id AS id,
			SUM(b.capacity) AS pv_cap,
			COUNT(b.geom) AS pv_cnt
		FROM	model_draft.powerplant_per_mun AS a, -- area
			model_draft.powerplant AS b -- point
		WHERE  	a.geom && b.geom AND
			ST_CONTAINS(a.geom,b.geom) AND
			b.technology = 'PV'
		GROUP BY a.id
		)AS t2
	WHERE  	t1.id = t2.id;

-- wind
UPDATE 	model_draft.powerplant_per_mun AS t1
	SET  	wind_cap = t2.wind_cap,
		wind_cnt = t2.wind_cnt
	FROM	(SELECT	a.id AS id,
			SUM(b.capacity) AS wind_cap,
			COUNT(b.geom) AS wind_cnt
		FROM	model_draft.powerplant_per_mun AS a, -- area
			model_draft.powerplant AS b -- point
		WHERE  	a.geom && b.geom AND
			ST_CONTAINS(a.geom,b.geom) AND
			b.technology = 'Wind'
		GROUP BY a.id
		)AS t2
	WHERE  	t1.id = t2.id;

-- sum
UPDATE 	model_draft.powerplant_per_mun AS t1
	SET  	sum_cap = COALESCE(pv_cap,0) + COALESCE(wind_cap,0),
		sum_cnt = COALESCE(pv_cnt,0) + COALESCE(wind_cnt,0);

-- metadata
COMMENT ON TABLE model_draft.powerplant_per_mun IS '{
	"title": "Renewable powerplant_per_mun",
	"description": "sample data",
	"language": [ "eng" ],
	"reference_date": "2017-04-19",
	"sources": [
		{"name": " ", "description": " ","url": " ", "license": " ", "copyright": " "} ],
	"spatial": [
		{"extend": "Test area",
		"resolution": ""} ],
	"license": [
		{"id": "ODbL-1.0",
		"name": "Open Data Commons Open Database License 1.0",
		"version": "1.0",
		"url": "https://opendatacommons.org/licenses/odbl/1.0/",
		"instruction": "You are free: To Share, To Create, To Adapt; As long as you: Attribute, Share-Alike, Keep open!",
		"copyright": " "} ],
	"contributors": [
		{"name": "Ludee", "email": " ", "date": "2017-04-18", "comment": "Create data"} ],
	"resources": [{
		"schema": {
			"fields": [
				{"name": "id", "description": "unique identifier", "unit": "" },
				{"name": "technology", "description": "wind or pv", "unit": "" },
				{"name": "capacity", "description": "installed capacity", "unit": "kW" },
				{"name": "geom", "description": "geometry", "unit": "" } ]},
		"meta_version": "1.2"}] }';
SELECT obj_description('model_draft.powerplant_per_mun' ::regclass) ::json;

-- scenariolog (version,io,schema_name,table_name,script_name,comment)
SELECT scenariolog('v1','output','model_draft','powerplant_per_mun','postgis_functions.sql',' ');
