/*
table template

__copyright__ 	= "© Reiner Lemoine Institut"
__license__ 	= "GNU Affero General Public License Version 3 (AGPL-3.0)"
__author__ 	= "Ludwig Huelk"
*/

-- table
DROP TABLE IF EXISTS	model_draft.templatetable CASCADE;
CREATE TABLE 		model_draft.templatetable (
	version 	text,
	id 		serial,
	name		text,
	description	text,
	lat 		double precision,
	lon 		double precision,
	geom_point 	geometry(POINT,4326),
	geom_polygon 	geometry(POLYGON,4326),
	geom_multipolygon 	geometry(MULTIPOLYGON,4326),
	geom_line 	geometry(LINESTRING,4326),
	CONSTRAINT templatetable_pkey PRIMARY KEY (version,id));

-- fkey
ALTER TABLE model_draft.templatetable
	ADD CONSTRAINT templatetable_fkey FOREIGN KEY (version) 
		REFERENCES model_draft.scenariolist(version) MATCH SIMPLE ON UPDATE NO ACTION ON DELETE NO ACTION;

-- grant
ALTER TABLE		model_draft.templatetable OWNER TO role_user;
GRANT SELECT ON TABLE	model_draft.templatetable TO role_read;

-- index
CREATE INDEX templatetable_geom_point_idx ON model_draft.templatetable USING GIST (geom_point);
CREATE INDEX templatetable_geom_polygon_idx ON model_draft.templatetable USING GIST (geom_polygon);
CREATE INDEX templatetable_geom_multipolygon_idx ON model_draft.templatetable USING GIST (geom_multipolygon);
CREATE INDEX templatetable_geom_line_idx ON model_draft.templatetable USING GIST (geom_line);

-- metadata
COMMENT ON TABLE model_draft.templatetable IS '{
	"title": "Test table with geometries",
	"description": " ",
	"language": [ "eng" ],
	"reference_date": "2017-04-19",
	"sources": [
		{"name": " ", "description": " ","url": " ", "license": " ", "copyright": " "} ],
	"spatial": [
		{"extend": "Test area",
		"resolution": ""} ],
	"license": [
		{"id": "ODbL-1.0",
		"name": "Open Data Commons Open Database License 1.0",
		"version": "1.0",
		"url": "https://opendatacommons.org/licenses/odbl/1.0/",
		"instruction": "You are free: To Share, To Create, To Adapt; As long as you: Attribute, Share-Alike, Keep open!",
		"copyright": " "} ],
	"contributors": [
		{"name": "Ludee", "email": " ", "date": "2017-04-18", "comment": "Create tempalte"} ],
	"resources": [{
		"schema": {
			"fields": [
				{"name": "version", "description": "version id", "unit": "" },
				{"name": "id", "description": "unique identifier", "unit": "" },
				{"name": "name", "description": "name of the object", "unit": "" },
				{"name": "description", "description": "description of the object", "unit": "" },
				{"name": "lat", "description": "lattitude in UTM", "unit": "" },
				{"name": "lon", "description": "longitude in UTM", "unit": "" },
				{"name": "geom_point", "description": "geometry", "unit": "" },
				{"name": "geom_polygon", "description": "geometry", "unit": "" },
				{"name": "geom_multipolygon", "description": "geometry", "unit": "" },
				{"name": "geom_line", "description": "geometry", "unit": "" },
				{"name": "geom", "description": "geometry", "unit": "" },	
				{"name": "", "description": "", "unit": "" } ]},
		"meta_version": "1.2"}] }';
SELECT obj_description('model_draft.templatetable' ::regclass) ::json;

-- scenariolog (version,io,schema_name,table_name,script_name,comment)
SELECT scenariolog('v1','output','model_draft','templatetable','table_template.sql',' ');
