/*
database schema setup

__copyright__ 	= "© Reiner Lemoine Institut"
__license__ 	= "GNU Affero General Public License Version 3 (AGPL-3.0)"
__author__ 	= "Ludwig Huelk"
*/

-- boundaries
CREATE SCHEMA boundaries; COMMENT ON SCHEMA boundaries IS 'legal land descriptions. examples: political and administrative boundaries'; 
GRANT ALL ON SCHEMA boundaries TO role_user WITH GRANT OPTION;
ALTER DEFAULT PRIVILEGES IN SCHEMA boundaries GRANT ALL ON TABLES TO role_user;
ALTER DEFAULT PRIVILEGES IN SCHEMA boundaries GRANT ALL ON SEQUENCES TO role_user;
GRANT USAGE ON SCHEMA boundaries TO role_read WITH GRANT OPTION;
ALTER DEFAULT PRIVILEGES IN SCHEMA boundaries GRANT SELECT ON TABLES TO role_read;
ALTER DEFAULT PRIVILEGES IN SCHEMA boundaries GRANT SELECT ON SEQUENCES TO role_read;
ALTER SCHEMA boundaries OWNER TO role_admin;

-- climate
CREATE SCHEMA climate; COMMENT ON SCHEMA climate IS 'processes and phenomena of the atmosphere. examples: cloud cover, weather, climate, atmospheric conditions, climate change, precipitation';
GRANT ALL ON SCHEMA climate TO role_user WITH GRANT OPTION;
ALTER DEFAULT PRIVILEGES IN SCHEMA climate GRANT ALL ON TABLES TO role_user;
ALTER DEFAULT PRIVILEGES IN SCHEMA climate GRANT ALL ON SEQUENCES TO role_user;
GRANT USAGE ON SCHEMA climate TO role_read WITH GRANT OPTION;
ALTER DEFAULT PRIVILEGES IN SCHEMA climate GRANT SELECT ON TABLES TO role_read;
ALTER DEFAULT PRIVILEGES IN SCHEMA climate GRANT SELECT ON SEQUENCES TO role_read;
ALTER SCHEMA climate OWNER TO role_admin;

-- economy
CREATE SCHEMA economy; COMMENT ON SCHEMA economy IS 'economic activities, conditions and employment. examples: production, labour, revenue, commerce, industry, tourism and ecotourism, forestry, fisheries, commercial or subsistence hunting, exploration and exploitation of resources such as minerals, oil and gas';
GRANT ALL ON SCHEMA economy TO role_user WITH GRANT OPTION;
ALTER DEFAULT PRIVILEGES IN SCHEMA economy GRANT ALL ON TABLES TO role_user;
ALTER DEFAULT PRIVILEGES IN SCHEMA economy GRANT ALL ON SEQUENCES TO role_user;
GRANT USAGE ON SCHEMA economy TO role_read WITH GRANT OPTION;
ALTER DEFAULT PRIVILEGES IN SCHEMA economy GRANT SELECT ON TABLES TO role_read;
ALTER DEFAULT PRIVILEGES IN SCHEMA economy GRANT SELECT ON SEQUENCES TO role_read;
ALTER SCHEMA economy OWNER TO role_admin;

-- energy_demand
CREATE SCHEMA energy_demand; COMMENT ON SCHEMA energy_demand IS 'consumption and use of energy. examples: peak loads, load curves';
GRANT ALL ON SCHEMA energy_demand TO role_user WITH GRANT OPTION;
ALTER DEFAULT PRIVILEGES IN SCHEMA energy_demand GRANT ALL ON TABLES TO role_user;
ALTER DEFAULT PRIVILEGES IN SCHEMA energy_demand GRANT ALL ON SEQUENCES TO role_user;
GRANT USAGE ON SCHEMA energy_demand TO role_read WITH GRANT OPTION;
ALTER DEFAULT PRIVILEGES IN SCHEMA energy_demand GRANT SELECT ON TABLES TO role_read;
ALTER DEFAULT PRIVILEGES IN SCHEMA energy_demand GRANT SELECT ON SEQUENCES TO role_read;
ALTER SCHEMA energy_demand OWNER TO role_admin;

-- energy_grid
CREATE SCHEMA energy_grid; COMMENT ON SCHEMA energy_grid IS 'energy transmission infrastructure. examples: power lines, substation, pipelines';
GRANT ALL ON SCHEMA energy_grid TO role_user WITH GRANT OPTION;
ALTER DEFAULT PRIVILEGES IN SCHEMA energy_grid GRANT ALL ON TABLES TO role_user;
ALTER DEFAULT PRIVILEGES IN SCHEMA energy_grid GRANT ALL ON SEQUENCES TO role_user;
GRANT USAGE ON SCHEMA energy_grid TO role_read WITH GRANT OPTION;
ALTER DEFAULT PRIVILEGES IN SCHEMA energy_grid GRANT SELECT ON TABLES TO role_read;
ALTER DEFAULT PRIVILEGES IN SCHEMA energy_grid GRANT SELECT ON SEQUENCES TO role_read;
ALTER SCHEMA energy_grid OWNER TO role_admin;

-- energy_supply
CREATE SCHEMA energy_supply; COMMENT ON SCHEMA energy_supply IS 'conversion (generation) of energy. examples: power stations, renewables';
GRANT ALL ON SCHEMA energy_supply TO role_user WITH GRANT OPTION;
ALTER DEFAULT PRIVILEGES IN SCHEMA energy_supply GRANT ALL ON TABLES TO role_user;
ALTER DEFAULT PRIVILEGES IN SCHEMA energy_supply GRANT ALL ON SEQUENCES TO role_user;
GRANT USAGE ON SCHEMA energy_supply TO role_read WITH GRANT OPTION;
ALTER DEFAULT PRIVILEGES IN SCHEMA energy_supply GRANT SELECT ON TABLES TO role_read;
ALTER DEFAULT PRIVILEGES IN SCHEMA energy_supply GRANT SELECT ON SEQUENCES TO role_read;
ALTER SCHEMA energy_supply OWNER TO role_admin;

-- environment
CREATE SCHEMA environment; COMMENT ON SCHEMA environment IS 'environmental resources, protection and conservation. examples: environmental pollution, waste storage and treatment, environmental impact assessment, monitoring environmental risk, nature reserves, landscape';
GRANT ALL ON SCHEMA environment TO role_user WITH GRANT OPTION;
ALTER DEFAULT PRIVILEGES IN SCHEMA environment GRANT ALL ON TABLES TO role_user;
ALTER DEFAULT PRIVILEGES IN SCHEMA environment GRANT ALL ON SEQUENCES TO role_user;
GRANT USAGE ON SCHEMA environment TO role_read WITH GRANT OPTION;
ALTER DEFAULT PRIVILEGES IN SCHEMA environment GRANT SELECT ON TABLES TO role_read;
ALTER DEFAULT PRIVILEGES IN SCHEMA environment GRANT SELECT ON SEQUENCES TO role_read;
ALTER SCHEMA environment OWNER TO role_admin;

-- model_draft
CREATE SCHEMA model_draft; COMMENT ON SCHEMA model_draft IS 'modelling sandbox, temp tables. examples: ego_grid_loadareas';
GRANT ALL ON SCHEMA model_draft TO role_user WITH GRANT OPTION;
ALTER DEFAULT PRIVILEGES IN SCHEMA model_draft GRANT ALL ON TABLES TO role_user;
ALTER DEFAULT PRIVILEGES IN SCHEMA model_draft GRANT ALL ON SEQUENCES TO role_user;
GRANT USAGE ON SCHEMA model_draft TO role_read WITH GRANT OPTION;
ALTER DEFAULT PRIVILEGES IN SCHEMA model_draft GRANT SELECT ON TABLES TO role_read;
ALTER DEFAULT PRIVILEGES IN SCHEMA model_draft GRANT SELECT ON SEQUENCES TO role_read;
ALTER SCHEMA model_draft OWNER TO role_admin;

-- reference
CREATE SCHEMA reference; COMMENT ON SCHEMA reference IS 'sources, literature';
GRANT ALL ON SCHEMA reference TO role_user WITH GRANT OPTION;
ALTER DEFAULT PRIVILEGES IN SCHEMA reference GRANT ALL ON TABLES TO role_user;
ALTER DEFAULT PRIVILEGES IN SCHEMA reference GRANT ALL ON SEQUENCES TO role_user;
GRANT USAGE ON SCHEMA reference TO role_read WITH GRANT OPTION;
ALTER DEFAULT PRIVILEGES IN SCHEMA reference GRANT SELECT ON TABLES TO role_read;
ALTER DEFAULT PRIVILEGES IN SCHEMA reference GRANT SELECT ON SEQUENCES TO role_read;
ALTER SCHEMA reference OWNER TO role_admin;

-- scenario
CREATE SCHEMA scenario; COMMENT ON SCHEMA scenario IS 'scenario data';
GRANT ALL ON SCHEMA scenario TO role_user WITH GRANT OPTION;
ALTER DEFAULT PRIVILEGES IN SCHEMA scenario GRANT ALL ON TABLES TO role_user;
ALTER DEFAULT PRIVILEGES IN SCHEMA scenario GRANT ALL ON SEQUENCES TO role_user;
GRANT USAGE ON SCHEMA scenario TO role_read WITH GRANT OPTION;
ALTER DEFAULT PRIVILEGES IN SCHEMA scenario GRANT SELECT ON TABLES TO role_read;
ALTER DEFAULT PRIVILEGES IN SCHEMA scenario GRANT SELECT ON SEQUENCES TO role_read;
ALTER SCHEMA scenario OWNER TO role_admin;

-- society
CREATE SCHEMA society; COMMENT ON SCHEMA society IS 'characteristics of society and cultures. examples: settlements, anthropology, archaeology, education, traditional beliefs, manners and customs, demographic data, recreational areas and activities, social impact assessments, crime and justice, census information';
GRANT ALL ON SCHEMA society TO role_user WITH GRANT OPTION;
ALTER DEFAULT PRIVILEGES IN SCHEMA society GRANT ALL ON TABLES TO role_user;
ALTER DEFAULT PRIVILEGES IN SCHEMA society GRANT ALL ON SEQUENCES TO role_user;
GRANT USAGE ON SCHEMA society TO role_read WITH GRANT OPTION;
ALTER DEFAULT PRIVILEGES IN SCHEMA society GRANT SELECT ON TABLES TO role_read;
ALTER DEFAULT PRIVILEGES IN SCHEMA society GRANT SELECT ON SEQUENCES TO role_read;
ALTER SCHEMA society OWNER TO role_admin;

-- public
GRANT ALL ON SCHEMA public TO role_user WITH GRANT OPTION;
ALTER DEFAULT PRIVILEGES IN SCHEMA public GRANT ALL ON TABLES TO role_user;
ALTER DEFAULT PRIVILEGES IN SCHEMA public GRANT ALL ON SEQUENCES TO role_user;
GRANT USAGE ON SCHEMA public TO role_read WITH GRANT OPTION;
ALTER DEFAULT PRIVILEGES IN SCHEMA public GRANT SELECT ON TABLES TO role_read;
ALTER DEFAULT PRIVILEGES IN SCHEMA public GRANT SELECT ON SEQUENCES TO role_read;
